import * as i0 from '@angular/core';
import { forwardRef, Component, ChangeDetectionStrategy, ViewEncapsulation, ViewChild, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, ReactiveFormsModule } from '@angular/forms';
import { coerceBooleanProperty } from '@bravobit/bb-foundation';
import { CommonModule } from '@angular/common';

let nextUniqueId = 0;
class BbiCheckbox {
    constructor(_renderer) {
        this._renderer = _renderer;
        // Readonly data.
        this.labelId = `bbi-checkbox-${nextUniqueId++}`;
        // Methods.
        this.onChange = () => ({});
        this.onTouched = () => ({});
        // State.
        this._grouped = false;
        this._disabled = false;
        this._indeterminate = false;
    }
    // Inputs.
    set disabled(value) {
        const disabled = coerceBooleanProperty(value);
        this.setDisabledState(disabled);
    }
    set grouped(value) {
        this._grouped = coerceBooleanProperty(value);
    }
    set indeterminate(value) {
        const indeterminate = coerceBooleanProperty(value);
        this.setIndeterminateState(indeterminate);
    }
    ngOnInit() {
        this.setDisabledState(this._disabled);
        this.setIndeterminateState(this._indeterminate);
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this._disabled = isDisabled;
        this.setProperty('disabled', this._disabled);
    }
    setIndeterminateState(indeterminate) {
        this._indeterminate = indeterminate;
        this.setProperty('indeterminate', this._indeterminate);
    }
    writeValue(newValue) {
        this.setProperty('checked', newValue);
    }
    onChangeEvent(event) {
        this.onChange(event?.target?.checked);
    }
    setProperty(key, value) {
        const element = this.inputElementRef?.nativeElement;
        if (!element) {
            return;
        }
        this._renderer.setProperty(element, key, value);
    }
}
BbiCheckbox.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: BbiCheckbox, deps: [{ token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
BbiCheckbox.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.0", type: BbiCheckbox, selector: "bbi-checkbox", inputs: { grouped: "grouped", disabled: "disabled", indeterminate: "indeterminate" }, host: { properties: { "class.grouped": "_grouped", "class.indeterminate": "_indeterminate" }, classAttribute: "bbi-checkbox" }, providers: [
        { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbiCheckbox), multi: true }
    ], viewQueries: [{ propertyName: "inputElementRef", first: true, predicate: ["input"], descendants: true, static: true }], ngImport: i0, template: "<input #input\n       [id]=\"labelId\"\n       (change)=\"onChangeEvent($event)\"\n       (blur)=\"onTouched()\"\n       class=\"bbi-checkbox-input\"\n       type=\"checkbox\">\n<label [attr.for]=\"labelId\"\n       class=\"bbi-checkbox-label\">\n    <span class=\"bbi-checkbox-text\"\n          dir=\"auto\"><ng-content></ng-content></span>\n</label>\n", styles: [".bbi-checkbox{display:block}.bbi-checkbox+.bbi-checkbox{margin-top:3px}.bbi-checkbox.grouped{margin-bottom:20px}.bbi-checkbox-input{border:0;width:1px;padding:0;height:1px;margin:-1px;overflow:hidden;position:absolute;visibility:inherit;white-space:nowrap;clip:rect(0,0,0,0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:before{border:1px solid #1565c0;background-color:#1565c0}.bbi-checkbox-input:checked+.bbi-checkbox-label:after,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{opacity:1;transform:scale(1) rotate(-45deg)}.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{top:-1px;left:5px;width:10px;border-left:0 solid white;border-bottom:2px solid white;transform:scale(1) rotate(0)}.bbi-checkbox-input:focus+.bbi-checkbox-label:before{outline-color:#1565c0}.bbi-checkbox-input:disabled+.bbi-checkbox-label{color:#c6c6c6;cursor:not-allowed}.bbi-checkbox-input:disabled+.bbi-checkbox-label:before{border-color:#c6c6c6}.bbi-checkbox-input:checked:disabled+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate:disabled+.bbi-checkbox-label:before{background-color:#c6c6c6}.bbi-checkbox-label{border:0;margin:0;display:flex;cursor:pointer;font-size:16px;font-weight:400;line-height:1.28;-webkit-user-select:none;user-select:none;position:relative;padding-left:20px;font-family:inherit;vertical-align:initial}.bbi-checkbox-label:before{left:0;width:20px;content:\"\";height:20px;position:absolute;border-radius:4px;outline-offset:1px;border:1px solid #111111;background-color:initial;outline:2px solid transparent;transition:outline-color .2s cubic-bezier(0,0,.2,1),background-color .18s cubic-bezier(0,0,.2,1),border-color .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-label:after{left:4px;opacity:0;width:12px;height:6px;content:\"\";margin-top:6px;background:none;position:absolute;transform-origin:center;border-left:2px solid white;border-bottom:2px solid white;transform:scale(.85) rotate(-60deg);transition:opacity .12s cubic-bezier(0,0,.2,1),transform .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-text{padding-left:6px}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: BbiCheckbox, decorators: [{
            type: Component,
            args: [{ selector: 'bbi-checkbox', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        { provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => BbiCheckbox), multi: true }
                    ], host: {
                        'class': 'bbi-checkbox',
                        '[class.grouped]': '_grouped',
                        '[class.indeterminate]': '_indeterminate'
                    }, inputs: ['grouped'], preserveWhitespaces: false, template: "<input #input\n       [id]=\"labelId\"\n       (change)=\"onChangeEvent($event)\"\n       (blur)=\"onTouched()\"\n       class=\"bbi-checkbox-input\"\n       type=\"checkbox\">\n<label [attr.for]=\"labelId\"\n       class=\"bbi-checkbox-label\">\n    <span class=\"bbi-checkbox-text\"\n          dir=\"auto\"><ng-content></ng-content></span>\n</label>\n", styles: [".bbi-checkbox{display:block}.bbi-checkbox+.bbi-checkbox{margin-top:3px}.bbi-checkbox.grouped{margin-bottom:20px}.bbi-checkbox-input{border:0;width:1px;padding:0;height:1px;margin:-1px;overflow:hidden;position:absolute;visibility:inherit;white-space:nowrap;clip:rect(0,0,0,0)}.bbi-checkbox-input:checked+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:before{border:1px solid #1565c0;background-color:#1565c0}.bbi-checkbox-input:checked+.bbi-checkbox-label:after,.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{opacity:1;transform:scale(1) rotate(-45deg)}.bbi-checkbox-input:indeterminate+.bbi-checkbox-label:after{top:-1px;left:5px;width:10px;border-left:0 solid white;border-bottom:2px solid white;transform:scale(1) rotate(0)}.bbi-checkbox-input:focus+.bbi-checkbox-label:before{outline-color:#1565c0}.bbi-checkbox-input:disabled+.bbi-checkbox-label{color:#c6c6c6;cursor:not-allowed}.bbi-checkbox-input:disabled+.bbi-checkbox-label:before{border-color:#c6c6c6}.bbi-checkbox-input:checked:disabled+.bbi-checkbox-label:before,.bbi-checkbox-input:indeterminate:disabled+.bbi-checkbox-label:before{background-color:#c6c6c6}.bbi-checkbox-label{border:0;margin:0;display:flex;cursor:pointer;font-size:16px;font-weight:400;line-height:1.28;-webkit-user-select:none;user-select:none;position:relative;padding-left:20px;font-family:inherit;vertical-align:initial}.bbi-checkbox-label:before{left:0;width:20px;content:\"\";height:20px;position:absolute;border-radius:4px;outline-offset:1px;border:1px solid #111111;background-color:initial;outline:2px solid transparent;transition:outline-color .2s cubic-bezier(0,0,.2,1),background-color .18s cubic-bezier(0,0,.2,1),border-color .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-label:after{left:4px;opacity:0;width:12px;height:6px;content:\"\";margin-top:6px;background:none;position:absolute;transform-origin:center;border-left:2px solid white;border-bottom:2px solid white;transform:scale(.85) rotate(-60deg);transition:opacity .12s cubic-bezier(0,0,.2,1),transform .18s cubic-bezier(0,0,.2,1)}.bbi-checkbox-text{padding-left:6px}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.Renderer2 }]; }, propDecorators: { inputElementRef: [{
                type: ViewChild,
                args: ['input', { static: true }]
            }], disabled: [{
                type: Input
            }], grouped: [{
                type: Input
            }], indeterminate: [{
                type: Input
            }] } });

class CheckboxModule {
}
CheckboxModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: CheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CheckboxModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: CheckboxModule, declarations: [BbiCheckbox], imports: [CommonModule, ReactiveFormsModule], exports: [BbiCheckbox] });
CheckboxModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: CheckboxModule, imports: [[CommonModule, ReactiveFormsModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: CheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, ReactiveFormsModule],
                    declarations: [BbiCheckbox],
                    exports: [BbiCheckbox]
                }]
        }] });

class ControlsModule {
}
ControlsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: ControlsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ControlsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: ControlsModule, imports: [CheckboxModule], exports: [CheckboxModule] });
ControlsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: ControlsModule, imports: [[CheckboxModule], CheckboxModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.0", ngImport: i0, type: ControlsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CheckboxModule],
                    exports: [CheckboxModule]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BbiCheckbox, CheckboxModule, ControlsModule };
//# sourceMappingURL=bravobit-bb-foundation-controls.mjs.map
